linkml
=======

Homepages
* https://linkml.github.io/linkml/ -- Link modeling language

Docs
* https://linkml.github.io/linkml-model/docs

Contact
* Chris Mungall cjmungall AT lbl DOT gov @cmungall
* Harold Solbrig solbrig@jhu.edu
